OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Compartilhado com você",
    "Shared with others" : "Compartilhado com outros",
    "Shared by link" : "Compartilhado por link",
    "Nothing shared with you yet" : "Nada foi compartilhado com você até agora",
    "Files and folders others share with you will show up here" : "Arquivos e pastas que outros compartilham com você serão mostrados aqui",
    "Nothing shared yet" : "Nada compartilhado até agora",
    "Files and folders you share will show up here" : "Arquivos e pastas que você compartilha serão mostrados aqui",
    "No shared links" : "Nenhum link compartilhado",
    "Files and folders you share by link will show up here" : "Arquivos e pastas que você compartilha por link serão mostrados aqui",
    "You can upload into this folder" : "Você não pode enviar arquivos para esta pasta",
    "No compatible server found at {remote}" : "Nenhum servidor compativel encontrado em {remote}",
    "Invalid server URL" : "URL do servidor inválida",
    "Failed to add the public link to your Nextcloud" : "Ocorreu uma falha ao adicionar o link público ao seu Nextcloud",
    "Share" : "Compartilhar",
    "No expiration date set" : "Nenhuma data de expiração definida",
    "Shared by" : "Compartilhado por",
    "Sharing" : "Compartilhando",
    "File shares" : "Compartilhamentos de arquivos",
    "Downloaded via public link" : "Baixado via link público",
    "Downloaded by {email}" : "Baixado por {email}",
    "{file} downloaded via public link" : "{file} baixado via link público",
    "{email} downloaded {file}" : "{email} baixou {file}",
    "Shared with group {group}" : "Compartilhou com o grupo {group}",
    "Removed share for group {group}" : "Excluiu o compartilhamento para o grupo {group}",
    "{actor} shared with group {group}" : "{actor} compartilhou com o grupo {group}",
    "{actor} removed share for group {group}" : "{actor} excluiu o compartilhamento para o grupo {group}",
    "You shared {file} with group {group}" : "Você compartilhou {file} com o grupo {group} ",
    "You removed group {group} from {file}" : "Você excluiu o grupo {group} de {file}",
    "{actor} shared {file} with group {group}" : "{actor} compartilhou {file} com o grupo {group}",
    "{actor} removed group {group} from {file}" : "{actor} excluiu o grupo {group} de {file}",
    "Shared as public link" : "Compartilhado como um link publico",
    "Removed public link" : "Excluído o link público",
    "Public link expired" : "O link público expirou",
    "{actor} shared as public link" : "{actor} compartilhou como um link publico",
    "{actor} removed public link" : "{actor} excluiu o link publico",
    "Public link of {actor} expired" : "O link público de {actor} expirou.",
    "You shared {file} as public link" : "Você compartilhou {file} como um link publico",
    "You removed public link for {file}" : "Você excluiu o link publico de {file}",
    "Public link expired for {file}" : "O link público de {file} expirou",
    "{actor} shared {file} as public link" : "{actor} compartilhou {file} como um link publico",
    "{actor} removed public link for {file}" : "{actor} excluiu o link publico de {file}",
    "Public link of {actor} for {file} expired" : "O link público de {actor} para {file} expirou",
    "{user} accepted the remote share" : "{user} aceitou o compartilhamento remoto",
    "{user} declined the remote share" : "{user} declinou o compartilhamento remoto",
    "You received a new remote share {file} from {user}" : "Você recebeu um novo compartilhamento remoto {file} de {user}",
    "{user} accepted the remote share of {file}" : "{user} aceitou o compartilhamento remoto de {file}",
    "{user} declined the remote share of {file}" : "{user} declinou do compartilhamento remoto de {file}",
    "{user} unshared {file} from you" : "{user} descompartilhou {file} de você",
    "Shared with {user}" : "Compartilhado com {user}",
    "Removed share for {user}" : "Excluiu compartilhamento para {user}",
    "{actor} shared with {user}" : "{actor} compartilhado com {user}",
    "{actor} removed share for {user}" : "{actor} excluiu o compartilhamento para {user}",
    "Shared by {actor}" : "Compartilhado por {actor}",
    "{actor} removed share" : "{actor} compartilhamento removido",
    "You shared {file} with {user}" : "Você compartilhou {arquivo} com {user}",
    "You removed {user} from {file}" : "Você excluiu {user} de {file}",
    "{actor} shared {file} with {user}" : "{actor} compartilhou {file} com {user}",
    "{actor} removed {user} from {file}" : "{actor} excluiu {user} de {file}",
    "{actor} shared {file} with you" : "{actor} compartilhou {file} com você",
    "{actor} removed you from {file}" : "{actor} excluiu você de {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Um arquivo ou pasta compartilhado por e-mail ou por link publico foi <strong>baixado</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Um arquivo ou pasta foi compartilhado a partir de <strong>outro servidor</strong>",
    "A file or folder has been <strong>shared</strong>" : "Um arquivo ou pasta foi <strong>compartilhado</strong> ",
    "Wrong share ID, share doesn't exist" : "ID de compartilhamento errado, o compartilhamento não existe",
    "could not delete share" : "não foi possível excluir o compartilhamento",
    "Could not delete share" : "Não foi possível excluir o compartilhamento",
    "Please specify a file or folder path" : "Por favor especifique um arquivo ou um caminho de pasta",
    "Wrong path, file/folder doesn't exist" : "Caminho errado, o arquivo ou pasta não existe",
    "Could not create share" : "Não foi possível criar o compartilhamento",
    "invalid permissions" : "permissões inválidas",
    "Please specify a valid user" : "Por favor especifique um usuário válido",
    "Group sharing is disabled by the administrator" : "O compartilhamento para grupos foi desabilitado pelo administrador",
    "Please specify a valid group" : "Por favor especifique um grupo válido",
    "Public link sharing is disabled by the administrator" : "O compartilhamento por link público foi desativado pelo administrador",
    "Public upload disabled by the administrator" : "O envio público foi desativado pelo administrador",
    "Public upload is only possible for publicly shared folders" : "O envio público só é possível para pastas compartilhadas publicamente",
    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser AAAA-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "O compartilhando %s falhou porque o serviço não permite ações de tipo %s",
    "You cannot share to a Circle if the app is not enabled" : "Você não pode compartilhar para um círculo se o aplicativo não está habilitado",
    "Please specify a valid circle" : "Por favor especifique um círculo válido",
    "Unknown share type" : "Tipo de compartilhamento desconhecido",
    "Not a directory" : "Não é um diretório",
    "Could not lock path" : "Não foi possível bloquear o caminho",
    "Wrong or no update parameter given" : "O parâmetro da atualização fornecido está errado ou não existe",
    "Can't change permissions for public share links" : "Não foi possível alterar as permissões para links de compartilhamento público",
    "Cannot increase permissions" : "Não foi possível aumentar as permissões",
    "%s is publicly shared" : "%s está compartilhado publicamente",
    "Share API is disabled" : "O compartilhamento de API está desabilitado.",
    "File sharing" : "Compartilhamento de arquivo",
    "This share is password-protected" : "Este compartilhamento é protegido por senha",
    "The password is wrong. Try again." : "Senha incorreta. Tente novamente.",
    "Password" : "Senha",
    "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
    "Name" : "Nome",
    "Share time" : "Data de compartilhamento",
    "Expiration date" : "Data de expiração",
    "Sorry, this link doesn’t seem to work anymore." : "Desculpe, este link parece não funcionar mais.",
    "Reasons might be:" : "As razões podem ser:",
    "the item was removed" : "o item foi removido",
    "the link expired" : "o link expirou",
    "sharing is disabled" : "o compartilhamento está desativado",
    "For more info, please ask the person who sent this link." : "Para mais informações, pergunte à pessoa que lhe enviou o link.",
    "shared by %s" : "compartilhado por %s",
    "Add to your Nextcloud" : "Adicionar ao seu Nextcloud",
    "Download" : "Baixar",
    "Download %s" : "Baixar %s",
    "Direct link" : "Link direto",
    "Upload files to %s" : "Enviar arquivos para %s",
    "Select or drop files" : "Selecione ou solte arquivos",
    "Uploading files…" : "Enviando arquivos...",
    "Uploaded files:" : "Arquivos enviados:"
},
"nplurals=2; plural=(n > 1);");
